@@ -2,6 +2,7 @@ import json
 import os
 
 import pandas as pd
+from rich.progress import Progress
 
 
 def process_and_append_data(file_path, df):
@@ -24,12 +25,18 @@ def main(input_dir: str, output: str, sort_by: str):
         print("No JSON files found in the input directory.", input_dir)
         return
 
-    for file_name in json_files:
-        file_path = os.path.join(input_dir, file_name)
-        df = process_and_append_data(file_path, df)
+    with Progress() as progress:
+        task = progress.add_task("Processing JSON file", total=len(json_files))
+        for file_name in json_files:
+            file_path = os.path.join(input_dir, file_name)
+            df = process_and_append_data(file_path, df)
+            progress.update(
+                task,
+                advance=1,
+            )
 
     # print(df.head())
-    df["sl"] = range(len(df))
+    df["sl"] = pd.RangeIndex(start=1, stop=len(df) + 1)
     df = df.reindex(columns=[sort_by, *df.columns[:-1]])
     df.sort_values(by=sort_by, inplace=True)
     df.to_excel(output, index=False)
