@@ -7,8 +7,11 @@ from typing import Optional, Any
 from uuid import UUID, uuid5
 from app.setup.utils import config_file
 import concurrent.futures
+from rich import print
+from rich.progress import TaskID, Progress
 
 config = configparser.ConfigParser()
+scraping_tasks = ""
 config.read(config_file())
 
 PROVIDERS = {
@@ -120,12 +123,21 @@ def _request(
     target_url: str = options["url"]
     type: Optional[str] = options["type"]
     skipImages: bool = options["skip_images"]
+    taskId: TaskID = options["task_id"]
+    progress: Progress = options["progress"]
+
+    try:
+        response = client.post(
+            endpoint,
+            json={"url": target_url, "type": type},
+            headers={"x-screenapi-key": config.get("default", "api_key")},
+        )
+    except Exception as error:
+        print(f"Current URL: {target_url}")
+        print(f"Error: {error}")
+        print("Exiting...")
+        exit(1)
 
-    response = client.post(
-        endpoint,
-        json={"url": target_url, "type": type},
-        headers={"x-screenapi-key": config.get("default", "api_key")},
-    )
     jsonResponse = response.json()
 
     if "image" in jsonResponse and not skipImages:
@@ -154,7 +166,8 @@ def _request(
     try:
         with open(output_filename, "w") as file:
             dump(jsonResponse, file, indent=2)
-        print(f"Saved to {output_filename}")
+        # print(f"Saved to {output_filename}")
+        progress.update(taskId, advance=1)
     except Exception as error:
         print(f"Error saving to {output_filename}: {error}")
 
@@ -165,6 +178,7 @@ async def main(
     overwrite: Optional[bool] = False,
     skip_images: Optional[bool] = False,
 ):
+    global scraping_tasks
     urls = read_urls_from_file(urls_file)
     mapped_urls = generate_mapped_urls(urls)
     done_already = []
@@ -178,27 +192,34 @@ async def main(
     client = Client(
         http2=True,
         timeout=None,
+        follow_redirects=True,
         base_url=config.get("default", "api_url"),
     )
 
     max_workers = max_workers if max_workers is not None else 10
-    with concurrent.futures.ThreadPoolExecutor(max_workerss=max_workers) as executor:
-        mapped_urls = [d for d in mapped_urls if getId(d["url"]) not in done_already]
-        executor.map(
-            _request,
-            [
-                {
-                    "client": client,
-                    "skip_images": skip_images,
-                    "endpoint": d["endpoint"],
-                    "key": d["key"],
-                    "url": d["url"],
-                    "type": d["type"],
-                }
-                for d in mapped_urls
-            ],
-        )
-        executor.shutdown(wait=True)
+    with concurrent.futures.ThreadPoolExecutor(max_workers=max_workers) as executor:
+        with Progress() as progress:
+            mapped_urls = [
+                d for d in mapped_urls if getId(d["url"]) not in done_already
+            ]
+            scraping_tasks = progress.add_task("Scraping", total=len(mapped_urls))
+            executor.map(
+                _request,
+                [
+                    {
+                        "client": client,
+                        "skip_images": skip_images,
+                        "endpoint": d["endpoint"],
+                        "key": d["key"],
+                        "url": d["url"],
+                        "type": d["type"],
+                        "task_id": scraping_tasks,
+                        "progress": progress,
+                    }
+                    for d in mapped_urls
+                ],
+            )
+            executor.shutdown(wait=True)
     print("Done!")
 
 
